@@ -33,5 +33,8 @@ def call_post_api(path, data):
 	res = requests.post(path, json = data)
 	# レスポンスの分解
 	status_code = res.status_code
-	json_str = res.text
-	return status_code, json_str
+	if status_code == 200:
+		json_obj = json.loads(res.text)
+	else:
+		json_obj = res.text
+	return status_code, json_obj
